# Reddcolors

A very simple library for color management alongside jupyterthemes.

# Overview
Reddcolors is a very simple tool for color management for working alongside [jupyterthemes](https://github.com/dunovank/jupyter-themes).

# Dependencies

This code makes use of:
  - matplotlib
  - Jupyter ([Anaconda](https://www.anaconda.com) recommended)
  - [jupyterthemes](https://github.com/dunovank/jupyter-themes)

Most of them come with conda, if some are missing they can be easily installed with pip.

# Installation

In the console type in
```sh
pip3 install reddcolors
```

```sh
# upgrade to latest version
pip install --upgrade reddcolors
```

# Usage

I'll write something here soon.

